@@ -7,6 +7,7 @@ It provides functionality for
 * reading current brightness in 3 directions (DPT 9.004)
 * reading current alarms (DPTBinary)
 * reading current wind speed in m/s (DPT 9.005)
+* reading current wind bearing in degrees (DPT 5.003)
 * reading current air pressure (DPT 9.006)
 * reading current humidity (DPT 9.007)
 
@@ -86,13 +87,14 @@ class Weather(Device):
         group_address_brightness_west: Optional["GroupAddressableType"] = None,
         group_address_brightness_east: Optional["GroupAddressableType"] = None,
         group_address_wind_speed: Optional["GroupAddressableType"] = None,
+        group_address_wind_bearing: Optional["GroupAddressableType"] = None,
         group_address_rain_alarm: Optional["GroupAddressableType"] = None,
         group_address_frost_alarm: Optional["GroupAddressableType"] = None,
         group_address_wind_alarm: Optional["GroupAddressableType"] = None,
         group_address_day_night: Optional["GroupAddressableType"] = None,
         group_address_air_pressure: Optional["GroupAddressableType"] = None,
         group_address_humidity: Optional["GroupAddressableType"] = None,
-        expose_sensors: bool = False,
+        create_sensors: bool = False,
         sync_state: bool = True,
         device_updated_cb: Optional[DeviceCallbackType] = None,
     ) -> None:
@@ -160,6 +162,16 @@ class Weather(Device):
             after_update_cb=self.after_update,
         )
 
+        self._wind_bearing = RemoteValueSensor(
+            xknx,
+            group_address_state=group_address_wind_bearing,
+            sync_state=sync_state,
+            value_type="angle",
+            device_name=self.name,
+            feature_name="Wind bearing",
+            after_update_cb=self.after_update,
+        )
+
         self._rain_alarm = RemoteValueSwitch(
             xknx,
             group_address_state=group_address_rain_alarm,
@@ -212,25 +224,24 @@ class Weather(Device):
             after_update_cb=self.after_update,
         )
 
-        if expose_sensors:
-            self.expose_sensors()
+        if create_sensors:
+            self.create_sensors()
 
-    def _iter_remote_values(self) -> Iterator[RemoteValue]:
+    def _iter_remote_values(self) -> Iterator[RemoteValue[Any]]:
         """Iterate the devices remote values."""
-        yield from [
-            self._temperature,
-            self._brightness_south,
-            self._brightness_north,
-            self._brightness_east,
-            self._brightness_west,
-            self._wind_speed,
-            self._rain_alarm,
-            self._wind_alarm,
-            self._frost_alarm,
-            self._day_night,
-            self._air_pressure,
-            self._humidity,
-        ]
+        yield self._temperature
+        yield self._brightness_south
+        yield self._brightness_north
+        yield self._brightness_east
+        yield self._brightness_west
+        yield self._wind_speed
+        yield self._wind_bearing
+        yield self._rain_alarm
+        yield self._wind_alarm
+        yield self._frost_alarm
+        yield self._day_night
+        yield self._air_pressure
+        yield self._humidity
 
     async def process_group_write(self, telegram: "Telegram") -> None:
         """Process incoming and outgoing GROUP WRITE telegram."""
@@ -279,6 +290,11 @@ class Weather(Device):
         """Return wind speed in m/s."""
         return self._wind_speed.value  # type: ignore
 
+    @property
+    def wind_bearing(self) -> Optional[int]:
+        """Return wind bearing in °."""
+        return self._wind_bearing.value  # type: ignore
+
     @property
     def rain_alarm(self) -> Optional[bool]:
         """Return True if rain alarm False if not."""
@@ -319,7 +335,7 @@ class Weather(Device):
             self.brightness_east,
         )
 
-    def expose_sensors(self) -> None:
+    def create_sensors(self) -> None:
         """Expose sensors to xknx."""
         for suffix, group_address in (
             ("_rain_alarm", self._rain_alarm.group_address_state),
@@ -365,6 +381,11 @@ class Weather(Device):
                 self._wind_speed.group_address_state,
                 "wind_speed_ms",
             ),
+            (
+                "_wind_bearing",
+                self._wind_bearing.group_address_state,
+                "angle",
+            ),
             (
                 "_air_pressure",
                 self._air_pressure.group_address_state,
@@ -431,13 +452,14 @@ class Weather(Device):
         group_address_brightness_west = config.get("group_address_brightness_west")
         group_address_brightness_east = config.get("group_address_brightness_east")
         group_address_wind_speed = config.get("group_address_wind_speed")
+        group_address_wind_bearing = config.get("group_address_wind_bearing")
         group_address_rain_alarm = config.get("group_address_rain_alarm")
         group_address_frost_alarm = config.get("group_address_frost_alarm")
         group_address_wind_alarm = config.get("group_address_wind_alarm")
         group_address_day_night = config.get("group_address_day_night")
         group_address_air_pressure = config.get("group_address_air_pressure")
         group_address_humidity = config.get("group_address_humidity")
-        expose_sensors = config.get("expose_sensors", False)
+        create_sensors = config.get("create_sensors", False)
         sync_state = config.get("sync_state", True)
 
         return cls(
@@ -449,13 +471,14 @@ class Weather(Device):
             group_address_brightness_west=group_address_brightness_west,
             group_address_brightness_east=group_address_brightness_east,
             group_address_wind_speed=group_address_wind_speed,
+            group_address_wind_bearing=group_address_wind_bearing,
             group_address_rain_alarm=group_address_rain_alarm,
             group_address_frost_alarm=group_address_frost_alarm,
             group_address_wind_alarm=group_address_wind_alarm,
             group_address_day_night=group_address_day_night,
             group_address_air_pressure=group_address_air_pressure,
             group_address_humidity=group_address_humidity,
-            expose_sensors=expose_sensors,
+            create_sensors=create_sensors,
             sync_state=sync_state,
         )
 
@@ -464,7 +487,7 @@ class Weather(Device):
         return (
             '<Weather name="{}" '
             'temperature="{}" brightness_south="{}" brightness_north="{}" brightness_west="{}" '
-            'brightness_east="{}" wind_speed="{}" rain_alarm="{}" '
+            'brightness_east="{}" wind_speed="{}" wind_bearing="{}" rain_alarm="{}" '
             'wind_alarm="{}" frost_alarm="{}" day_night="{}" '
             'air_pressure="{}" humidity="{}" />'.format(
                 self.name,
@@ -474,6 +497,7 @@ class Weather(Device):
                 self._brightness_west.group_addr_str(),
                 self._brightness_east.group_addr_str(),
                 self._wind_speed.group_addr_str(),
+                self._wind_bearing.group_addr_str(),
                 self._rain_alarm.group_addr_str(),
                 self._wind_alarm.group_addr_str(),
                 self._frost_alarm.group_addr_str(),
