@@ -5,15 +5,20 @@ Connect requests are used to start a new tunnel connection on a KNX/IP device.
 With a Connect Response the receiving party acknowledges the valid processing of the request,
 assigns a communication channel and an individual address for the client.
 """
+from typing import TYPE_CHECKING, List, Optional
+
 from xknx.exceptions import CouldNotParseKNXIP
 
-from .body import KNXIPBody
+from .body import KNXIPBodyResponse
 from .error_code import ErrorCode
 from .hpai import HPAI
 from .knxip_enum import ConnectRequestType, KNXIPServiceType
 
+if TYPE_CHECKING:
+    from xknx.xknx import XKNX
 
-class ConnectResponse(KNXIPBody):
+
+class ConnectResponse(KNXIPBodyResponse):
     """Representation of a KNX Connect Response."""
 
     # pylint: disable=too-many-instance-attributes
@@ -24,12 +29,12 @@ class ConnectResponse(KNXIPBody):
 
     def __init__(
         self,
-        xknx,
+        xknx: "XKNX",
         communication_channel: int = 0,
         status_code: ErrorCode = ErrorCode.E_NO_ERROR,
-        request_type: ConnectRequestType = None,
+        request_type: ConnectRequestType = ConnectRequestType.TUNNEL_CONNECTION,
         control_endpoint: HPAI = HPAI(),
-        identifier: int = None,
+        identifier: Optional[int] = None,
     ):
         """Initialize ConnectResponse class."""
         super().__init__(xknx)
@@ -37,20 +42,18 @@ class ConnectResponse(KNXIPBody):
         self.communication_channel = communication_channel
         self.status_code = status_code
         self.request_type = request_type
-        self.control_endpoint = HPAI()
+        self.control_endpoint = control_endpoint
         # identifier shall contain KNX Individual Address assigned to this KNXnet/IP Tunnelling connection
         self.identifier = identifier
 
-    def calculated_length(self):
+    def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
-        if self.status_code == ErrorCode.E_NO_ERROR:
-            return 2 + HPAI.LENGTH + ConnectResponse.CRD_LENGTH
-        return 2
+        return 2 + HPAI.LENGTH + ConnectResponse.CRD_LENGTH
 
-    def from_knx(self, raw):
+    def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
 
-        def crd_from_knx(crd):
+        def crd_from_knx(crd: bytes) -> int:
             """Parse CRD (Connection Response Data Block)."""
             if crd[0] != ConnectResponse.CRD_LENGTH:
                 raise CouldNotParseKNXIP("CRD has wrong length")
@@ -67,13 +70,18 @@ class ConnectResponse(KNXIPBody):
         if self.status_code == ErrorCode.E_NO_ERROR:
             pos += self.control_endpoint.from_knx(raw[pos:])
             pos += crd_from_knx(raw[pos:])
+        else:
+            # do not parse HPAI and CRD in case of errors - just check length
+            pos += len(raw[pos:])
         return pos
 
-    def to_knx(self):
+    def to_knx(self) -> List[int]:
         """Serialize to KNX/IP raw data."""
 
-        def crd_to_knx():
+        def crd_to_knx() -> List[int]:
             """Serialize CRD (Connect Response Data Block)."""
+            assert self.identifier is not None
+
             crd = []
             crd.append(ConnectResponse.CRD_LENGTH)
             crd.append(self.request_type.value)
@@ -84,14 +92,12 @@ class ConnectResponse(KNXIPBody):
         data = []
         data.append(self.communication_channel)
         data.append(self.status_code.value)
-
-        if self.status_code == ErrorCode.E_NO_ERROR:
-            data.extend(self.control_endpoint.to_knx())
-            data.extend(crd_to_knx())
+        data.extend(self.control_endpoint.to_knx())
+        data.extend(crd_to_knx())
 
         return data
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return object as readable string."""
         return (
             '<ConnectResponse communication_channel="{}" '
