@@ -3,26 +3,32 @@ Module for managing an RGB remote value.
 
 DPT 232.600.
 """
-from typing import List
+from typing import TYPE_CHECKING, List, Optional, Sequence, Tuple, Union
 
-from xknx.dpt import DPTArray
+from xknx.dpt import DPTArray, DPTBinary
 from xknx.exceptions import ConversionError
 
-from .remote_value import RemoteValue
+from .remote_value import AsyncCallbackType, RemoteValue
+
+if TYPE_CHECKING:
+    from xknx.telegram.address import GroupAddressableType
+    from xknx.xknx import XKNX
 
 
-class RemoteValueColorRGB(RemoteValue):
+class RemoteValueColorRGB(RemoteValue[DPTArray]):
     """Abstraction for remote value of KNX DPT 232.600 (DPT_Color_RGB)."""
 
+    # pylint: disable=no-self-use
+
     def __init__(
         self,
-        xknx,
-        group_address=None,
-        group_address_state=None,
-        device_name=None,
-        feature_name="Color RGB",
-        after_update_cb=None,
-        passive_group_addresses: List[str] = None,
+        xknx: "XKNX",
+        group_address: Optional["GroupAddressableType"] = None,
+        group_address_state: Optional["GroupAddressableType"] = None,
+        device_name: Optional[str] = None,
+        feature_name: str = "Color RGB",
+        after_update_cb: Optional[AsyncCallbackType] = None,
+        passive_group_addresses: Optional[List["GroupAddressableType"]] = None,
     ):
         """Initialize remote value of KNX DPT 232.600 (DPT_Color_RGB)."""
         # pylint: disable=too-many-arguments
@@ -36,11 +42,17 @@ class RemoteValueColorRGB(RemoteValue):
             passive_group_addresses=passive_group_addresses,
         )
 
-    def payload_valid(self, payload):
+    def payload_valid(
+        self, payload: Optional[Union[DPTArray, DPTBinary]]
+    ) -> Optional[DPTArray]:
         """Test if telegram payload may be parsed."""
-        return isinstance(payload, DPTArray) and len(payload.value) == 3
+        return (
+            payload
+            if isinstance(payload, DPTArray) and len(payload.value) == 3
+            else None
+        )
 
-    def to_knx(self, value):
+    def to_knx(self, value: Sequence[int]) -> DPTArray:
         """Convert value to payload."""
         if not isinstance(value, (list, tuple)):
             raise ConversionError(
@@ -65,6 +77,6 @@ class RemoteValueColorRGB(RemoteValue):
 
         return DPTArray(list(value))
 
-    def from_knx(self, payload):
+    def from_knx(self, payload: DPTArray) -> Tuple[int, int, int]:
         """Convert current payload to value."""
         return payload.value[0], payload.value[1], payload.value[2]
